Contrast to Noise Ratio (CNR)
=============================

.. automodule:: viqa.nr_metrics.cnr
    :exclude-members: CNR, contrast_to_noise_ratio


.. rubric:: Functions

.. currentmodule:: viqa.nr_metrics.cnr

.. autosummary::
    :toctree: generated/

    contrast_to_noise_ratio


.. rubric:: Classes

.. currentmodule:: viqa.nr_metrics.cnr

.. autosummary::
    :toctree: generated/
    :template: class.rst

    CNR